@@ -89,12 +89,12 @@ void ExportAlarmJob::slotWriteNextArchiveResource()
     Akonadi::AgentManager *manager = Akonadi::AgentManager::self();
     const Akonadi::AgentInstance::List list = manager->instances();
     if (mIndexIdentifier < list.count()) {
-        Akonadi::AgentInstance agent = list.at(mIndexIdentifier);
+        const Akonadi::AgentInstance agent = list.at(mIndexIdentifier);
         const QString identifier = agent.identifier();
         if (identifier.contains(QLatin1String("akonadi_kalarm_dir_resource_"))) {
             const QString archivePath = Utils::alarmPath() + identifier + QDir::separator();
 
-            QString url = Utils::resourcePath(agent);
+            const QString url = Utils::resourcePath(agent);
             if (!mAgentPaths.contains(url)) {
                 mAgentPaths << url;
                 if (!url.isEmpty()) {
@@ -109,7 +109,7 @@ void ExportAlarmJob::slotWriteNextArchiveResource()
                     connect(resourceJob, &ExportResourceArchiveJob::terminated, this, &ExportAlarmJob::slotAlarmJobTerminated);
                     resourceJob->start();
                 } else {
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Url is empty for " << identifier;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << "Url is empty for " << identifier;
                     QTimer::singleShot(0, this, &ExportAlarmJob::slotAlarmJobTerminated);
                 }
             } else {
